import { Flags } from "./flags/flag";
export default abstract class Command {
    /** Name of the command, defaults to name of class */
    static id?: string;
    /** Give description for command */
    static description?: string;
    /** String list of aliases for command. */
    static aliases?: string[];
    /** A object of flags for the command. */
    static flags?: Flags;
    /** List of sub commands. */
    static commands?: typeof Command[];
    /** Set default values for flags. */
    static defaults?: object;
    /**
     * User-defined application code. (called when running application)
     */
    abstract run(args?: string[], flags?: any, globals?: any): void;
    /**
     * User-defined exception handler.
     * Used to override the default error handler (throw error)
     */
    exception(error: Error): Promise<any>;
    /**
     * Throw an error with exit and error code, making tracing problems easier.
     */
    error(message: string | Error, options?: {
        code?: string;
        exit?: number;
    }): void;
    /**
     * Execute another command directly from a separate command.
     *
     * Note: If the flags parameter is used, the command will run directly and
     *       won't parse the args parameter as flags and strings.
     *
     * @param command The command to execute.
     * @param args The arguments passed to the command execution.
     * @param flags The flags provided for the command.
     */
    execute(command: typeof Command, args: string[], flags?: Flags, globals?: Flags): Promise<void>;
}
export declare function execute(executor: typeof Command, argv?: string[]): Promise<void>;
