"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const parser_1 = require("./flags/parser");
class Command {
    /**
     * User-defined exception handler.
     * Used to override the default error handler (throw error)
     */
    async exception(error) {
        throw error;
    }
    /**
     * Throw an error with exit and error code, making tracing problems easier.
     */
    error(message, options) {
        // TODO: Implement log handler for logging software like sentry.
        var _a, _b;
        let error;
        if (message instanceof Error) {
            error = message;
        }
        else {
            error = new Error(message);
        }
        const stack = error.stack.split("\n");
        error.stack = [
            stack[0],
            message instanceof Error ? [stack[1]] : [stack[2]]
        ].join("\n");
        error["code"] = ((_a = options) === null || _a === void 0 ? void 0 : _a.code) || "UNKNOWN_ERROR";
        error["exit"] = ((_b = options) === null || _b === void 0 ? void 0 : _b.exit) || 1;
        throw error;
    }
    /**
     * Execute another command directly from a separate command.
     *
     * Note: If the flags parameter is used, the command will run directly and
     *       won't parse the args parameter as flags and strings.
     *
     * @param command The command to execute.
     * @param args The arguments passed to the command execution.
     * @param flags The flags provided for the command.
     */
    async execute(command, args, flags, globals) {
        if (flags) {
            const instance = new command();
            return await instance.run(args, flags, globals);
        }
        await execute(command, args);
    }
}
exports.default = Command;
async function execute(executor, argv) {
    var _a;
    const { command, flags, args, globals } = parser_1.parse(executor, argv);
    const instance = new command();
    let exit = 0;
    try {
        await instance.run(args, flags, globals || {});
    }
    catch (err) {
        await instance.exception(err);
        exit = ((_a = err) === null || _a === void 0 ? void 0 : _a.code) || 1;
    }
    process.exit(exit);
}
exports.execute = execute;
//# sourceMappingURL=command.js.map