"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function parseCommand(command, argv, parent) {
    var _a, _b, _c, _d, _e;
    let result = {
        command: command,
        flags: ((_a = parent) === null || _a === void 0 ? void 0 : _a.flags) || {},
        globals: Object.assign({}, (_b = parent) === null || _b === void 0 ? void 0 : _b.flags),
        args: []
    };
    let flags = command.flags || {};
    const name = argument => (argument.startsWith("--") ? argument.slice(2) : argument.slice(1)).split("=")[0];
    const f = flag => (flags[flag] && flag) ||
        Object.keys(flags).find(f => flags[f].char == flag) ||
        flag;
    while (argv.length > 0) {
        let argument = argv[0];
        // Validate if argument is a flag.
        if (argument.startsWith("-")) {
            // Save the flag name for later.
            let flag = name(argument);
            let value = argument.split("=")[1];
            // Check if the flag is a super flag.
            // Super Flag is when a flag only starts with a single - and contains multiple letters.
            // E.g. 'command -gfh' then it's important to split the flags into bits like ['g', 'f', 'h'] and parse them as individual flags.
            if (!argument.startsWith("--") && argument.length >= 3) {
                argv.shift(); // Remove the flag from the argv array.
                argv.unshift(...flag.split("").map(i => "-" + i)); // Fill the array with the flags from the super flag.
                continue; // Skip the super flag.
            }
            if (((_c = flags[f(flag)]) === null || _c === void 0 ? void 0 : _c.type) === "string" && !result.flags[f(flag)]) {
                // If the value is already found, no reason to look deeper to find it.
                if (value || result.flags[f(flag)]) {
                    result.flags[f(flag)] = value;
                    continue;
                }
                // Search for the next string in argv, and use result as value.
                let i = 0;
                let args = [...argv];
                while ((_d = args.shift()) === null || _d === void 0 ? void 0 : _d.startsWith("-")) {
                    i++;
                    result.flags[f(flag)] = args[0];
                }
                // Removes the value, so the parser don't think it's a command or argument later.
                argv.splice(i, 1);
            }
            else if (((_e = flags[f(flag)]) === null || _e === void 0 ? void 0 : _e.type) === "boolean") {
                // Just some basic conversion of a boolean value. (allowed values: 'false', '0' else true)
                result.flags[f(flag)] =
                    value === undefined
                        ? true
                        : value === "false"
                            ? false
                            : value === "0"
                                ? false
                                : true;
            }
            else if (!result.flags[f(flag)]) {
                result.flags[f(flag)] = true;
            }
        }
        else {
            const forward = ((argument, command) => { var _a; return (_a = command.commands) === null || _a === void 0 ? void 0 : _a.find((command) => {
                var _a, _b, _c;
                return ((_a = command.id) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === argument.toLowerCase() ||
                    ((_b = command.name) === null || _b === void 0 ? void 0 : _b.toLowerCase()) === argument.toLowerCase() || ((_c = command.aliases) === null || _c === void 0 ? void 0 : _c.includes(argument.toLowerCase()));
            }); })(argument, command);
            if (forward) {
                argv.shift();
                return parseCommand(forward, argv, result);
            }
            result.args.push(argument);
        }
        argv.shift();
    }
    return result;
}
function parse(command, argv) {
    return parseCommand(command, argv);
}
exports.parse = parse;
//# sourceMappingURL=parser.js.map