"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
/**
 * Import Package utilities.
 */
const package_1 = require("./package");
const typescript_1 = require("./typescript");
const command_1 = require("../command");
async function run(options) {
    var _a, _b, _c;
    /**
     * Prevent LWCF to run multiple times, in case the use case includes the bin,
     * to be the same as the main script.
     */
    if (process.env["LWCF"] === "true")
        return;
    process.env["LWCF"] = "true";
    const rootDir = ((_a = options) === null || _a === void 0 ? void 0 : _a.dir) || package_1.locateProjectRoot();
    const pkgPath = path.resolve(rootDir, "package.json");
    let pkg;
    try {
        // Require package.json for identification of the main script.
        pkg = require(pkgPath);
    }
    catch (_d) {
        console.error(`Unable to locate package.json at '${pkgPath}'`);
        process.exit(1);
    }
    // Find the main script with focus on build first.
    let script = path.resolve(rootDir, pkg.module || ((_b = pkg.directories) === null || _b === void 0 ? void 0 : _b.lib) || pkg.main);
    try {
        try {
            if (typescript_1.isTypeScript(rootDir)) {
                // Check if TS-Node is already running process.
                if (typescript_1.isTypeScriptInstance()) {
                    // Register TypeScript parser to allowing importing TypeScript files.
                    typescript_1.registerTypeScript(rootDir);
                }
                // Find the main script with focus on development first.
                script = path.resolve(rootDir, pkg.module || pkg.main || ((_c = pkg.directories) === null || _c === void 0 ? void 0 : _c.lib));
            }
        }
        catch (error) {
            // Throw error in case the main script isn't defined in the package.json.
            if (error.code === "ERR_INVALID_ARG_TYPE") {
                throw new Error("Unable to identify executable in '" + pkgPath + "'");
            }
        }
        const req = require(script);
        // Build command from required script. Check for default property for allowance of CommonJS.
        const command = req["default"] ? req.default : req;
        if (typeof command === "object")
            throw new Error("Script '" + script + "' does not export command.");
        // Execute the main command with automatic argument parsing.
        await command_1.execute(command, process.argv.slice(2));
    }
    catch (error) {
        // Throw error in case the script is missing export of the main command.
        if (error.message === "object.default is not a constructor") {
            throw new Error("Script '" + script + "' does not export command.");
        }
        if (error.message === "instance.run is not a function") {
            throw new Error("Command in '" + script + "' does not have a run function.");
        }
        throw error;
    }
}
exports.run = run;
//# sourceMappingURL=execute.js.map