"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
function isTypeScript(rootDir) {
    try {
        if (fs.existsSync(path.resolve(rootDir, "tsconfig.json")))
            return true;
    }
    catch (_a) {
        return false;
    }
    return false;
}
exports.isTypeScript = isTypeScript;
function isTypeScriptInstance() {
    return (typeof process[Symbol.for("ts-node.register.instance")] === "undefined");
}
exports.isTypeScriptInstance = isTypeScriptInstance;
function registerTypeScript(rootDir) {
    let typescript;
    try {
        typescript = require("typescript");
    }
    catch (_a) {
        try {
            typescript = require(rootDir + "/node_modules/typescript");
        }
        catch (_b) { }
    }
    const tsnodePath = require.resolve("ts-node", {
        paths: [rootDir, __dirname]
    });
    const tsnode = require(tsnodePath);
    const configPath = path.resolve(rootDir, "tsconfig.json");
    const config = typescript.parseConfigFileTextToJson(configPath, fs.readFileSync(configPath, "utf8")).config;
    const cwd = process.cwd();
    try {
        process.chdir(rootDir);
        tsnode.register({
            skipProject: true,
            transpileOnly: true,
            compilerOptions: Object.assign(config.compilerOptions, {
                esModuleInterop: config.compilerOptions.esModuleInterop,
                target: config.compilerOptions.target || "es2017",
                module: "commonjs",
                sourceMap: true,
                typeRoots: [`${rootDir}/node_modules/@types`]
            })
        });
    }
    finally {
        process.chdir(cwd);
    }
    return false;
}
exports.registerTypeScript = registerTypeScript;
//# sourceMappingURL=typescript.js.map